GPS Network Socket
======================

This module has a class GPSNetworkSocket and test scripts (server and client)

Advice
-------

This project has no extra requeriment python modules.

TO DO
------

* Documentation
* Examples
* Test with IP Socket
